using System;
using System.IO;

namespace Siberix.Examples
{
	class Example
	{
		static void Main(string[] args)
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Info
			report.Info.Title = "Example";
			report.Info.Author = "Siberix Technologies, Canada";
			report.Info.Creator = "Siberix Report Writer";
			report.Info.Copyright = "2003-2012 Siberix Technologies, Canada";

			// Section
			Siberix.Report.Section.ISection section = report.AddSection();
			section.Size = new Siberix.Report.PageSize(Siberix.Report.PageSize.Letter.Height / 2, Siberix.Report.PageSize.Letter.Width);
			section.Spacings.Horizontal = 35;
			section.Spacings.Top = 20;
			section.Spacings.Bottom = 5;
			section.Flip = true;

			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Black);
			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Red);
			Siberix.Report.Text.Style style3 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(10), Siberix.Graphics.Brushes.Black);

			// Page Numbering
			Siberix.Report.Section.IFooter footer = section.AddFooter();
			footer.Height = new Siberix.Report.DirectHeight(30);

			Siberix.Report.IPageNumber pn = footer.AddPageNumber(20, 5);
			pn.Style = style3;
			pn.Format = Siberix.Report.NumberFormat.Decimal;
			pn.Template = "Page {0} of {1}";
			pn.Alignment = Siberix.Report.NumberAlignment.Left;

			footer = section.AddFooter();
			footer.Height = new Siberix.Report.DirectHeight(30);

			pn = footer.AddPageNumber(375, 5);
			pn.Style = style3;
			pn.Format = Siberix.Report.NumberFormat.Decimal;
			pn.Template = "Page {0} of {1}";
			pn.Alignment = Siberix.Report.NumberAlignment.Right;

			// Content
			for (int i = 1; i < 108; i++)
			{
				Siberix.Report.Text.IText text = section.AddText();
				text.Style = style1;
				text.Spacings.Bottom = 5;
				text.AddContent(i.ToString(), style2);
				text.AddContent(" Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");
			}

			// Booklet
			Siberix.Report.IPageCollection pages = report.Generate();

			Siberix.Report.Report report2 = new Siberix.Report.Report();

			// Section
			section = report2.AddSection();
			section.Size = Siberix.Report.PageSize.Letter;
			section.Orientation = Siberix.Report.Orientation.Landscape;

			int k = 0;
			int cnt = pages.Count - 1;

			Siberix.Graphics.IGraphics graphics = null;

			float midX = Siberix.Report.PageSize.Letter.Height / 2;
			float btmY = Siberix.Report.PageSize.Letter.Width - 10;

			Siberix.Graphics.Pen pen = new Siberix.Graphics.Pen(Siberix.Graphics.Colors.DarkBlue, 0.5F, Graphics.DashStyle.Dash);

			foreach (Siberix.Report.IPage page in pages)
			{
				if ((k % 2) == 0)
				{
					Siberix.Report.ICanvas canvas = section.AddCanvas();

					canvas.Width = new Siberix.Report.RelativeWidth(100);
					canvas.Height = new Siberix.Report.RelativeHeight(100);

					graphics = canvas.AsGraphics();
				}
				else
				{
					graphics.Translate(Siberix.Report.PageSize.Letter.Height / 2, 0);

					if (k < cnt)
						section.AddPageBreak();
				}

				page.Draw(graphics);

				graphics.Pen = pen;

				graphics.DrawLine(midX, 10, midX, btmY);

				k++;
			}
			
			report2.Publish("Booklet.pdf", Siberix.Report.FileFormat.PDF);

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Booklet.pdf");
			process.StartInfo = info;
			process.Start();
		}
	}
}