using System;
using System.IO;

namespace Siberix.Examples
{
	class Example
	{
		static void Main(string[] args)
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Callback
			report.Callback = new Callback();

			// Load
			report.Load("../../Example.xml");

			// Publish
			report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF);
			report.Publish("Document.xps", Siberix.Report.FileFormat.XPS);

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Document.pdf");
			process.StartInfo = info;
			process.Start();
		}

		public class Callback : Siberix.Report.ICallback
		{
			public string OnMergeCode(string id)
			{
				if (id == null)
					return null;

				if (id.Equals("Company"))
					return "Siberix Technologies";

				return null;
			}

			public void OnInjector(string id, Siberix.Report.IElement element)
			{
				if ((element == null) || (id == null))
					return;

				if ((element.Type == Siberix.Report.ElementType.Group) && id.Equals("Injector1"))
				{
					Siberix.Report.IGroup group = (Siberix.Report.IGroup)element;

					Siberix.Report.Text.IText text = group.AddText();
					text.Style = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.DarkGreen);
					text.Spacings.Bottom = 5;
					text.AddContent("Group's injector test!");
				}
			}

			public void OnInjector(string id, Siberix.Report.Text.IText text, Siberix.Report.Text.Style style, Siberix.Report.Text.Hyperlink hyperlink)
			{
				if (id == null)
					return;

				if (id.Equals("UserName"))
				{
					if (style != null)
						style = new Siberix.Report.Text.Style(style.Font, Siberix.Graphics.Brushes.Blue);
					else
						style = new Siberix.Report.Text.Style(null, Siberix.Graphics.Brushes.Blue);

					text.AddContent("John", style);
				}
			}

			public Siberix.Report.Text.Style GetStyle(string id)
			{
				return null;
			}

			public Stream LoadFont(string path)
			{
				return null;
			}

			public Stream LoadImage(string path)
			{
				return null;
			}

			public Stream LoadMetafile(string path)
			{
				return null;
			}

			public Report.IDrawing OnDrawing(string id)
			{
				return null;
			}

			public void OnLoadEnd(Report.IElement element)
			{

			}

			public void OnLoadStart(Report.IElement element)
			{

			}

			public string ResolvePath(string path)
			{
				return path;
			}
		}
	}
}