using System;
using System.IO;

namespace Siberix.Examples
{
	class Example
	{
		static void Main(string[] args)
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Info
			report.Info.Title = "Example";
			report.Info.Author = "Siberix Technologies, Canada";
			report.Info.Creator = "Siberix Report Writer";
			report.Info.Copyright = "2003-2012 Siberix Technologies, Canada";

			// Section
			Siberix.Report.Section.ISection section = report.AddSection();
			section.Size = Siberix.Report.PageSize.Letter;
			section.Spacings.All = 35;

			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Black);

			Siberix.Report.IGroup group = section.AddGroup();
			group.Borders = new Siberix.Report.Borders(new Siberix.Graphics.Pen(Siberix.Graphics.Colors.DarkBlue, 3, Siberix.Graphics.DashStyle.Dash), 10);
			group.Spacings.Vertical = 10;
			group.Paddings.All = 10;
			group.Background.Brush = Siberix.Graphics.Brushes.WhiteSmoke;
			group.Background.Drawing = new CustomDrawing();

			Siberix.Report.Text.IText text = group.AddText();
			text.Width = new Siberix.Report.RelativeWidth(50);
			text.Style = style1;
			text.Interval = 2;
			text.Indent = 50;
			text.Alignment = Siberix.Report.TextAlignment.Left;
			text.AddContent("1. Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor. ");
			text.AddContent("2. Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor. ");
			text.AddContent("3. Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			// Publish
			report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF);
			report.Publish("Document.xps", Siberix.Report.FileFormat.XPS);

			// Save
			report.Save("Report.xml");

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Document.pdf");
			process.StartInfo = info;
			process.Start();
		}

		public class CustomDrawing : Siberix.Report.IDrawing
		{
			public string Id
			{
				get
				{
					return "Drawing1";
				}
			}

			public void OnDraw(Siberix.Graphics.IGraphics graphics, float x, float y, float width, float height)
			{
				Random rnd = new Random();

				for (int i = 0; i < 25; i++)
				{
					float radius = rnd.Next(25) + 5;
					float cx = x + rnd.Next((int)(width - radius * 2)) + radius;
					float cy = y + rnd.Next((int)(height - radius * 2)) + radius;

					byte r = (byte)(rnd.Next(155) + 100);
					byte g = (byte)(rnd.Next(155) + 100);
					byte b = (byte)(rnd.Next(155) + 100);

					graphics.Brush = new Siberix.Graphics.SolidColorBrush(new Siberix.Graphics.Color(r, g, b));
					graphics.FillEllipse(cx, cy, radius, radius);
				}
			}
		}
	}
}