namespace Siberix.Examples
{
	using System;
	using System.Collections.Generic;

	class Example
	{
		private class Task
		{
			public int Id { get; set; }
			public string Description { get; set; }
		}

		private class TemplateSelector1 : Siberix.Report.List.IItemTemplateSelector
		{
			public string Id
			{
				get
				{
					return "ts1";
				}
			}

			public Siberix.Report.List.IItemTemplate SelectItemTemplate(object item, int index, List<Siberix.Report.List.IItemTemplate> templates, Siberix.Report.List.IItemTemplateFactory factory)
			{
				if ((index + 1) % 5 == 0)
					return templates[1];

				return templates[0];
			}
		}

		static void Main(string[] args)
		{
			List<Task> tasks = new List<Task>();

			for (int i = 1; i < 26; i++)
			{
				tasks.Add(new Task() { Id = i, Description = i + ". Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor"});
			}

			TemplateSelector1 ts1 = new TemplateSelector1();

			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			report.DataContext = new Siberix.Report.Data.DataContext("dc1", tasks);

			report.Delegates.GetTemplateSelectorDelegate = delegate(string id)
			{
				if (id == ts1.Id)
					return ts1;

				return null;
			};

			// Load
			report.Load("../../Report.xml");

			// Publish
			report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF);
			report.Publish("Document.xps", Siberix.Report.FileFormat.XPS);

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Document.pdf");
			process.StartInfo = info;
			process.Start();
		}
	}
}