using System;
using System.IO;

namespace Siberix.Examples
{
	class Example
	{
		static void Main(string[] args)
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Info
			report.Info.Title = "Example";
			report.Info.Author = "Siberix Technologies, Canada";
			report.Info.Creator = "Siberix Report Writer";
			report.Info.Copyright = "2003-2012 Siberix Technologies, Canada";

			// Section
			Siberix.Report.Section.ISection section = report.AddSection();
			section.Size = Siberix.Report.PageSize.Letter;
			section.Spacings.All = 35;

			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(10), Siberix.Graphics.Brushes.Black);
			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(135), new Siberix.Graphics.SolidColorBrush(new Siberix.Graphics.Color(240, 240, 240)));

			// Page Numbering
			Siberix.Report.Section.IFooter footer = section.AddFooter();
			footer.Height = new Siberix.Report.DirectHeight(30);

			Siberix.Report.IPageNumber pn = footer.AddPageNumber(600, 5);
			pn.Style = style1;
			pn.Format = Siberix.Report.NumberFormat.Decimal;
			pn.Template = "Page {0} of {1}";
			pn.Alignment = Siberix.Report.NumberAlignment.Right;

			// Watermark
			Siberix.Report.Section.IWatermark watermark = section.AddWatermark();
			watermark.Repeat = true;

			Siberix.Report.Text.IText text = watermark.AddText(0, 0, -45);
			text.Style = style2;
			text.AddContent("TOC");

			// Bookmarks
			report.AddBookmark("ContentsRef", "Contents", false);
			report.AddBookmark("TextRef", "Text", false);
			report.AddBookmark("ImageRef", "Image", false);
			report.AddBookmark("ListRef", "List", false);

			AddCaption(section, Siberix.Graphics.Brushes.DarkBlue, 15, "ContentsRef", "Contents");
			AddContents(section);

			section.AddPageBreak();
			AddCaption(section, Siberix.Graphics.Brushes.DarkRed, 10, "TextRef", "Text");
			section.AddPageBreak();
			AddCaption(section, Siberix.Graphics.Brushes.DarkOrange, 10, "ImageRef", "Image");
			section.AddPageBreak();
			AddCaption(section, Siberix.Graphics.Brushes.DarkGreen, 10, "ListRef", "List");

			// Publish
			report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF);
			report.Publish("Document.xps", Siberix.Report.FileFormat.XPS);

			// Save
			report.Save("Document.xml");

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Document.pdf");
			process.StartInfo = info;
			process.Start();
		}

		private static void AddCaption(Siberix.Report.Section.ISection section, Siberix.Graphics.Brush bgbrush, float width, string id, string caption)
		{
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.White);

			Siberix.Report.IGroup group = section.AddGroup();
			group.Width = new Siberix.Report.RelativeWidth(width);
			group.Background.Brush = bgbrush;
			group.Borders.Corners.All = new Siberix.Report.Corner(null, 5);
			group.Borders.Corners.TopRight = new Siberix.Report.Corner(null, 10);
			group.Borders.Corners.BottomRight = new Siberix.Report.Corner(null, 10);
			group.Paddings.All = 5;
			group.Spacings.Top = 20;
			group.Spacings.Bottom = 15;
			group.KeepWithNext = true;

			Siberix.Report.Text.IText text = group.AddText();
			text.Style = style1;
			text.Id = id;
			text.AddContent(caption);
		}

		private static void AddContents(Siberix.Report.Section.ISection section)
		{
			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Black);

			// Contents
			Siberix.Report.Grid.IGrid grid = section.AddGrid();
			grid.Width = new Siberix.Report.RelativeWidth(70);

			Siberix.Report.Grid.IColumn column = grid.AddColumn();
			column.Width = new Siberix.Report.RelativeWidth(90);

			column = grid.AddColumn();
			column.Width = new Siberix.Report.RelativeWidth(10);

			// Text
			Siberix.Report.Grid.IRow row = grid.AddRow();
			row.Spacings.Top = 5;

			Siberix.Report.Grid.ICell cell = row.AddCell();

			Siberix.Report.Text.IText text = cell.AddText();
			text.Style = style1;
			text.Leader = new Siberix.Report.Text.Leader(".");
			text.Width = new Siberix.Report.RelativeWidth(100);
			text.AddContent("Text", new Siberix.Report.Text.Hyperlink("TextRef"));

			cell = row.AddCell();

			Siberix.Report.IPageReference pr = cell.AddPageReference("TextRef");
			pr.Style = style1;
			pr.Alignment = Siberix.Report.NumberAlignment.Left;

			// Image
			row = grid.AddRow();
			row.Spacings.Top = 5;

			cell = row.AddCell();

			text = cell.AddText();
			text.Style = style1;
			text.Leader = new Siberix.Report.Text.Leader(".");
			text.Width = new Siberix.Report.RelativeWidth(100);
			text.AddContent("Image", new Siberix.Report.Text.Hyperlink("ImageRef"));

			cell = row.AddCell();

			pr = cell.AddPageReference("ImageRef");
			pr.Style = style1;
			pr.Alignment = Siberix.Report.NumberAlignment.Left;

			// List
			row = grid.AddRow();
			row.Spacings.Top = 5;

			cell = row.AddCell();

			text = cell.AddText();
			text.Style = style1;
			text.Leader = new Siberix.Report.Text.Leader(".");
			text.Width = new Siberix.Report.RelativeWidth(100);
			text.AddContent("List", new Siberix.Report.Text.Hyperlink("ListRef"));

			cell = row.AddCell();

			pr = cell.AddPageReference("ListRef");
			pr.Style = style1;
			pr.Alignment = Siberix.Report.NumberAlignment.Left;
		}
	}
}