using System;
using System.IO;

namespace Siberix.Examples
{
	class Example
	{
		static void Main(string[] args)
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Extension Factory
			report.RegisterExtensionFactory("Factory1", new ExtensionFactory());

			// Info
			report.Info.Title = "Example";
			report.Info.Author = "Siberix Technologies, Canada";
			report.Info.Creator = "Siberix Report Writer";
			report.Info.Copyright = "2003-2012 Siberix Technologies, Canada";

			// Section
			Siberix.Report.Section.ISection section = report.AddSection();
			section.Size = Siberix.Report.PageSize.Letter;
			section.Spacings.All = 35;

			Siberix.Report.IFrame frame1 = section.AddFrame("Factory1", "Extension1");
			frame1.Width = new Siberix.Report.DirectWidth(150);
			frame1.Spacings.All = 10;
			((Extension)frame1.Extension).OuterColor = Siberix.Graphics.Colors.Green;

			Siberix.Report.IFrame frame2 = section.AddFrame("Factory1", "Extension1");
			frame2.Width = new Siberix.Report.DirectWidth(350);
			frame2.Spacings.All = 10;
			((Extension)frame2.Extension).InnerColor = Siberix.Graphics.Colors.Navy;

			// Publish
			report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF);
			report.Publish("Document.xps", Siberix.Report.FileFormat.XPS);

			// Save
			report.Save("Report.xml");

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Document.pdf");
			process.StartInfo = info;
			process.Start();

			/*
			Siberix.Report.Report report2 = new Siberix.Report.Report();
			report2.RegisterExtensionFactory("Factory1", new ExtensionFactory());
			report2.Load("Report.xml");
			report2.Publish("Extension2.pdf", Siberix.Report.FileFormat.PDF);
			 */
		}

		public class ExtensionFactory : Siberix.Report.IExtensionFactory
		{
			public Siberix.Report.IExtension CreateExtension(string id)
			{
				if (string.IsNullOrEmpty(id))
					return null;

				if (id.Equals("Extension1"))
					return new Extension("Factory1", "Extension1");

				return null;
			}
		}

		public class Extension : Siberix.Report.IExtension
		{
			private string _factoryId;
			private string _id;
			private Siberix.Graphics.Color _outerColor;
			private Siberix.Graphics.Color _innerColor;

			public Extension(string factoryId, string id)
			{
				_factoryId = factoryId;
				_id = id;
				_outerColor = Siberix.Graphics.Colors.Red;
				_innerColor = Siberix.Graphics.Colors.Blue;
			}

			public string FactoryId
			{
				get
				{
					return _factoryId;
				}
			}

			public string Id
			{
				get
				{
					return _id;
				}
			}

			public Siberix.Graphics.Color OuterColor
			{
				get
				{
					return _outerColor;
				}
				set
				{
					_outerColor = value;
				}
			}

			public Siberix.Graphics.Color InnerColor
			{
				get
				{
					return _innerColor;
				}
				set
				{
					_innerColor = value;
				}
			}

			public void Save(Stream stream)
			{
				StreamWriter sw = new StreamWriter(stream);

				sw.WriteLine(_outerColor.ToString());
				sw.WriteLine(_innerColor.ToString());

				sw.Flush();
			}

			public void Load(Stream stream)
			{
				StreamReader sr = new StreamReader(stream);

				_outerColor = Siberix.Graphics.Color.Parse(sr.ReadLine());
				_innerColor = Siberix.Graphics.Color.Parse(sr.ReadLine());
			}

			public Siberix.Graphics.Size OnMeasure(Siberix.Graphics.IGraphics graphics)
			{
				return new Siberix.Graphics.Size(100.0F, 100.0F);
			}

			public void OnDraw(Siberix.Graphics.IGraphics graphics, float x, float y, float width, float height)
			{
				graphics.Pen = new Siberix.Graphics.Pen(_outerColor, 3);
				graphics.DrawRoundRect(x, y, width, height, 25, 25);

				graphics.Pen = new Siberix.Graphics.Pen(_innerColor, 3, Siberix.Graphics.DashStyle.Dot);
				graphics.DrawRoundRect(x + 5, y + 5, width - 10, height - 10, 25, 25);
			}
		}
	}
}