Imports System
Imports System.IO

Module Example

    Sub Main()

        ' Report
        Dim report As Siberix.Report.Report = New Siberix.Report.Report()

        ' Info
        report.Info.Title = "Example"
        report.Info.Author = "Siberix Technologies, Canada"
        report.Info.Creator = "Siberix Report Writer"
        report.Info.Copyright = "2003-2012 Siberix Technologies, Canada"

        ' Extension Factory
        report.RegisterExtensionFactory("Factory1", New ExtensionFactory())

        ' Section
        Dim section As Siberix.Report.Section.ISection = report.AddSection()
        section.Size = Siberix.Report.PageSize.Letter
        section.Spacings.All = 35

        Dim frame1 As Siberix.Report.IFrame = section.AddFrame("Factory1", "Extension1")
        frame1.Width = New Siberix.Report.DirectWidth(150)
        frame1.Spacings.All = 10
        CType(frame1.Extension, Extension).OuterColor = Siberix.Graphics.Colors.Green

        Dim frame2 As Siberix.Report.IFrame = section.AddFrame("Factory1", "Extension1")
        frame2.Width = New Siberix.Report.DirectWidth(350)
        frame2.Spacings.All = 10
        CType(frame2.Extension, Extension).InnerColor = Siberix.Graphics.Colors.Navy

        ' Publish
        report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF)
        report.Publish("Document.xps", Siberix.Report.FileFormat.XPS)

        ' Save
        report.Save("Report.xml")

        ' View
        Dim process As System.Diagnostics.Process = New System.Diagnostics.Process()
        Dim info As System.Diagnostics.ProcessStartInfo = New System.Diagnostics.ProcessStartInfo("Document.pdf")
        process.StartInfo = info
        process.Start()

    End Sub

    Public Class ExtensionFactory
        Implements Siberix.Report.IExtensionFactory

        Public Function CreateExtension(ByVal id As String) As Siberix.Report.IExtension Implements Report.IExtensionFactory.CreateExtension

            If (String.IsNullOrEmpty(id)) Then
                Return Nothing
            End If

            If id.Equals("Extension1") Then
                Return New Extension("Factory1", "Extension1")
            End If

            Return Nothing

        End Function

    End Class

    Public Class Extension
        Implements Siberix.Report.IExtension

        Private _factoryId As String
        Private _id As String
        Private _outerColor As Siberix.Graphics.Color
        Private _innerColor As Siberix.Graphics.Color

        Public Sub New(ByVal factoryId As String, ByVal id As String)

            _factoryId = factoryId
            _id = id
            _outerColor = Siberix.Graphics.Colors.Red
            _innerColor = Siberix.Graphics.Colors.Blue

        End Sub

        Public ReadOnly Property FactoryId As String Implements Siberix.Report.IExtension.FactoryId

            Get
                Return _factoryId
            End Get

        End Property

        Public ReadOnly Property Id As String Implements Siberix.Report.IExtension.Id

            Get
                Return _id
            End Get

        End Property

        Public Property OuterColor As Siberix.Graphics.Color

            Get
                Return _outerColor
            End Get

            Set(ByVal value As Siberix.Graphics.Color)
                _outerColor = value
            End Set

        End Property

        Public Property InnerColor As Siberix.Graphics.Color

            Get
                Return _innerColor
            End Get

            Set(ByVal value As Siberix.Graphics.Color)
                _innerColor = value
            End Set

        End Property

        Public Sub Save(ByVal stream As System.IO.Stream) Implements Siberix.Report.IExtension.Save

            Dim sw As StreamWriter = New StreamWriter(stream)

            sw.WriteLine(_outerColor.ToString())
            sw.WriteLine(_innerColor.ToString())

            sw.Flush()

        End Sub

        Public Sub Load(ByVal stream As System.IO.Stream) Implements Siberix.Report.IExtension.Load

            Dim sr As StreamReader = New StreamReader(stream)

            _outerColor = Siberix.Graphics.Color.Parse(sr.ReadLine())
            _innerColor = Siberix.Graphics.Color.Parse(sr.ReadLine())

        End Sub

        Public Sub OnDraw(ByVal graphics As Siberix.Graphics.IGraphics, ByVal x As Single, ByVal y As Single, ByVal width As Single, ByVal height As Single) Implements Siberix.Report.IExtension.OnDraw

            graphics.Pen = New Siberix.Graphics.Pen(_outerColor, 3)
            graphics.DrawRoundRect(x, y, width, height, 25, 25)

            graphics.Pen = New Siberix.Graphics.Pen(_innerColor, 3, Siberix.Graphics.DashStyle.Dot)
            graphics.DrawRoundRect(x + 5, y + 5, width - 10, height - 10, 25, 25)

        End Sub

        Public Function OnMeasure(ByVal graphics As Siberix.Graphics.IGraphics) As Siberix.Graphics.Size Implements Siberix.Report.IExtension.OnMeasure

            Return New Siberix.Graphics.Size(100.0F, 100.0F)

        End Function

    End Class

End Module
